@@ -1,8 +1,10 @@
+//-*-c++-*-
 #ifndef INCLUDED_BehaviorBase_h_
 #define INCLUDED_BehaviorBase_h_
 
 #include "Events/EventListener.h"
 #include "Shared/ReferenceCounter.h"
+#include <string>
 
 //! The basis from which all other Behaviors should inherit
 /*! Makes use of ReferenceCounter so that behaviors can automatically delete themselves if wanted\n
@@ -11,18 +13,24 @@ class BehaviorBase : public ReferenceCounter, public EventListener {
  public:
 	//! constructor
 	BehaviorBase() : ReferenceCounter(), started(false) {}
-	//! destructor
-	virtual ~BehaviorBase()=0;
+	//! destructor - if is active when deleted, will call DoStop() first
+	virtual ~BehaviorBase() { SetAutoDelete(false); if(started) DoStop();  } //{ if(started) { references++; DoStop(); references--; } }
 	//! By default, merely adds to the reference counter (through AddReference()) @note you should still call this from your overriding methods
-	virtual void DoStart() { AddReference(); started=true;}
+	virtual void DoStart() { if(!started) { started=true; AddReference(); } }
 	//! By default, subtracts from the reference counter, and deletes if zero @note you should still call this when you override this @warning call this at the end of your DoStop(), not beginning (it might @c delete @c this )
-	virtual void DoStop() { started=false; RemoveReference(); }
+	virtual void DoStop() { if(started) { started=false; RemoveReference(); } }
 	//! Allows you to get away with not supplying a processEvent() function for the EventListener interface.  By default, does nothing.
 	virtual void processEvent(const EventBase& /*event*/) {};
 
 	
-	//! Used to identify the behavior in menus and such
-	virtual const char* getName() const =0;
+	//! Identifies the behavior in menus and such
+	virtual std::string getName() const =0;
+
+	//! Gives a short description of what this class of behaviors does... you should override this (but don't have to)
+	static std::string getClassDescription() { return ""; }
+
+	//! Gives a short description of what this particular instantiation does (in case a more specific description is needed)
+	virtual std::string getDescription() const { return getClassDescription(); }
 
 	//! Returns true if the behavior is currently running
 	virtual bool isActive() const { return started; }
@@ -36,10 +44,10 @@ class BehaviorBase : public ReferenceCounter, public EventListener {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_2 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-1_3 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2003/04/18 05:15:05 $
+ * $Date: 2003/06/09 08:05:08 $
  */
 
 #endif
