@@ -6,6 +6,7 @@
 #include "Shared/WorldState.h"
 #include "Motion/MMAccessor.h"
 #include "Motion/LedMC.h"
+#include "NullControl.h"
 
 //! when activated, this will print a battery report to stdout and light up LEDs to specify power level
 /*! The LEDs use the LedEngine::displayPercent() function, with minor/major style.  This means
@@ -24,19 +25,17 @@ class BatteryCheckControl : public ControlBase, public EventListener {
 public:
 
 	//!Constructor
-	BatteryCheckControl() : ControlBase("Battery Check"), display_id(MotionManager::invalid_MC_ID) {}
+	BatteryCheckControl() : ControlBase("Battery Check","Reports % power remaining, and gives details on console") {}
 
 	//!Destructor
 	virtual ~BatteryCheckControl() {}
 
 	//!Prints a report to stdio and lights up the face to show battery level
 	/*! keeps running until deactivated - will listen for power events and continue to update display */
-	virtual ControlBase * activate(MotionManager::MC_ID display) {
+	virtual ControlBase * activate(MotionManager::MC_ID display, Socket * gui) {
 		cout << "Press the \"back\" button to leave battery display" << endl;
-		display_id=display;
 		erouter->addListener(this,EventBase::powerEGID);
-		report();
-		return this;
+		return ControlBase::activate(display,gui);
 	}
 	//! stops listening for power events and sets display to invalid
 	virtual void pause() {
@@ -46,6 +45,19 @@ public:
 	//! calls report()
 	virtual void refresh() {
 		report();
+		if(gui_comm!=NULL && wireless->isConnected(gui_comm->sock)) {
+			char tmp[20];
+			sprintf(tmp,"%d",(unsigned int)(state->sensors[PowerRemainOffset]*100));
+			//		pushSlot(new NullControl(std::string("Power remain: ")+tmp+std::string("%"),"See console output for details"));
+			std::string s("refresh\n");
+			s+=getName()+"\n1\n0\n0\nPower remain: ";
+			s+=tmp;
+			s+="%\nSee console output for details\n";
+			s+="status\nPower remaining: ";
+			s+=tmp;
+			s+="%\n";
+			gui_comm->write((const byte*)s.c_str(),s.size());
+		}
 	}
 	//! stops listening for power events and sets display to invalid
 	virtual void deactivate() {
@@ -57,6 +69,9 @@ public:
 		if(event.getSourceID()!=PowerSourceID::VibrationSID)
 			refresh();
 	}
+	virtual ControlBase * doSelect() {
+		return this;
+	}
 	//! redisplay text to cout and refresh LED values
 	void report() {
 		cout << "BATTERY REPORT:" << endl;
@@ -83,12 +98,10 @@ public:
 		cout << endl;
 		if(display_id!=MotionManager::invalid_MC_ID) {
 			MMAccessor<LedMC> disp(display_id);
-			disp->displayPercent(state->sensors[PowerRemainOffset],LedEngine::minor,LedEngine::major);
+			disp->displayPercent(state->sensors[PowerRemainOffset],LedEngine::major,LedEngine::major);
 		}
 	}
 
-protected:
-	MotionManager::MC_ID display_id; //!< used to display power info using LEDs
 };
 
 /*! @file
@@ -96,10 +109,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_2 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-1_3 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2003/03/01 20:53:27 $
+ * $Date: 2003/06/09 08:05:12 $
  */
 
 #endif
