@@ -2,14 +2,14 @@
 #ifndef INCLUDED_BehaviorSwitchControl_h_
 #define INCLUDED_BehaviorSwitchControl_h_
 
-#include "MenuControl.h"
+#include "ControlBase.h"
 #include "Behaviors/BehaviorBase.h"
 #include "Shared/ReferenceCounter.h"
 #include "Shared/Factory.h"
 #include "Shared/debuget.h"
 
 //! Holds some utility classes and functions for BehaviorSwitchControl which shouldn't be stored in a templated class
-class BehaviorSwitchControlBase : public MenuControl {
+class BehaviorSwitchControlBase : public ControlBase {
 public:
 	//! A simple utility class to allow the BehaviorSwitchControl's to be able to deactivate the current behavior when a new one becomes active
 	/*! Most behaviors are either major actions which you'll only want one of active
@@ -30,7 +30,7 @@ public:
 	
 	//! constructor
 	BehaviorSwitchControlBase(const std::string& n, BehaviorGroup* bg, bool retain)
-		: MenuControl(n), retained(true), behgrp(bg) {
+		: ControlBase(n), retained(true), behgrp(bg) {
 		retained=retain;
 		if(behgrp!=NULL)
 			behgrp->AddReference();
@@ -50,12 +50,12 @@ public:
 
 	//! tells the current behavior (if there is one) to stop then loads its own
 	/*! @return NULL unless there are submenus */
-	virtual ControlBase * activate(MotionManager::MC_ID display) {
+	virtual ControlBase * activate(MotionManager::MC_ID display, Socket * gui) {
 		if(slotsSize()==0) {
 			toggle();
 			return NULL;
 		} else
-			return MenuControl::activate(display);
+			return ControlBase::activate(display,gui);
 	}
 
 protected:
@@ -90,6 +90,7 @@ public:
 	
 	//! destructor
 	virtual ~BehaviorSwitchControl() {
+		stop();
 		if(mybeh!=NULL && retained)
 			mybeh->RemoveReference();
 	}
@@ -101,11 +102,17 @@ public:
 	virtual BehaviorSwitchControl<B,Al>* toggle() { if(isRunning()) stopother(); else { stopother(); startmine(); } return this; }
 
 	//! adds a status to the name: - if in memory, # if running
-	virtual const char* getName() const {
+	virtual std::string getName() const {
 		if(!isValid())//(mybeh==NULL || !retained && (behgrp==NULL || behgrp->curBehavior!=mybeh))
-			return MenuControl::getName();
+			return ControlBase::getName();
 		else
-			return mybeh->getName();
+			return (mybeh->isActive()?'#':'-')+mybeh->getName();
+	}
+	virtual std::string getDescription() const {
+		if(!isValid() || mybeh->getDescription().size()==0)//(mybeh==NULL || !retained && (behgrp==NULL || behgrp->curBehavior!=mybeh))
+			return B::getClassDescription();
+		else
+			return mybeh->getDescription();
 	}
 	
 
@@ -175,10 +182,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_2 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-1_3 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2003/03/01 20:53:27 $
+ * $Date: 2003/06/10 00:53:47 $
  */
 
 #endif
