@@ -2,29 +2,34 @@
 #ifndef INCLUDED_EventLogger_h_
 #define INCLUDED_EventLogger_h_
 
-#include "MenuControl.h"
+#include "ControlBase.h"
 #include "Events/EventListener.h"
 #include <fstream>
 
 //! allows logging of events to the console or a file
-class EventLogger : public MenuControl, public EventListener {
+class EventLogger : public ControlBase, public EventListener {
 public:
 	//!constructor
 	EventLogger();
 
 	//!opens a custom (embedded) menu to toggle individual EGIDs
 	virtual ControlBase* doSelect();
+	
+	virtual void refresh();
 
 	//!sends all events received to stdout and/or logfile
 	virtual void processEvent(const EventBase& event);
 
-	//!Prompts for a filename and returns the string
-	std::string getFilename();
-
 protected:
 	//!sets the status char of slot @a i to @a c
 	void setStatus(unsigned int i, char c);
 
+	//!checks to see if logfilePath differs from the StringInputControl's value and switches it if it is
+	void checkLogFile();
+	
+	//!address of the logfile, if any (empty string is no logfile)
+	std::string logfilePath;
+
 	//!if a filename is given, events are logged to here
 	std::ofstream logfile;
 
@@ -37,10 +42,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_2 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-1_3 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2003/03/03 01:18:11 $
+ * $Date: 2003/06/09 08:05:12 $
  */
 
 #endif
