@@ -4,32 +4,36 @@
 #include <unistd.h>
 #include <dirent.h>
 
-ControlBase * FileBrowserControl::activate(MotionManager::MC_ID display) {
+ControlBase * FileBrowserControl::activate(MotionManager::MC_ID display, Socket * gui) {
 	rebuildmenu();
-	return MenuControl::activate(display);
+	return ControlBase::activate(display,gui);
 }
 
 ControlBase* FileBrowserControl::doSelect() {
-	MenuControl::doSelect();
-	if(cur>=options.size() || options[cur]==NULL)
-		return this;
-	std::string nm(options[cur]->getName());
-	if(nm[nm.size()-1]=='/' || nm=="..") {
-		if(nm=="..")
-			paths.pop_back();
-		else {
-			paths.push_back(nm.substr(0,nm.size()-1));
-			cur=0;
-		}
-		rebuildmenu();
-		refresh();
-		return this;
-	} else {
-		ControlBase * ret=selectedFile(makePath(nm));
-		if(ret==this)
+	for(unsigned int i=0; i<hilights.size(); i++) {
+		unsigned int cur=hilights[i];
+		if(cur>=options.size() || options[cur]==NULL)
+			continue;
+		ControlBase::doSelect();
+		std::string nm(options[cur]->getName());
+		if(nm[nm.size()-1]=='/' || nm=="..") {
+			if(hilights.size()>1)
+				continue;
+			if(nm=="..")
+				paths.pop_back();
+			else
+				paths.push_back(nm.substr(0,nm.size()-1));
+			rebuildmenu();
 			refresh();
-		return ret;
-	}	
+			return this;
+		} else {
+			ControlBase * ret=selectedFile(makePath(nm));
+			if(ret!=this)
+				return ret;
+		}
+	}
+	refresh();
+	return this;
 }
 
 void FileBrowserControl::setRoot(const std::string& path) {
@@ -130,6 +134,27 @@ void FileBrowserControl::rebuildmenu() {
 	closedir(dir);
 	if(options.size()==0)
 		pushSlot(new ControlBase("[empty directory]"));
-	if(cur>=options.size())
-		cur=options.size()-1;
+	else {
+		hilights.push_back(0);
+		/*	for(unsigned int i=0; i<hilights.size(); i++) {
+				if(hilights[i]>=options.size()) {
+				hilights.resize(i);
+				cout << "hilights resized at " << i << endl;
+				break;
+				}
+				}*/
+	}
 }
+
+
+/*! @file
+ * @brief Implements FileBrowserControl, which displays the contents of a directory
+ * @author ejt (Creator)
+ *
+ * $Author: ejt $
+ * $Name: tekkotsu-1_3 $
+ * $Revision: 1.7 $
+ * $State: Exp $
+ * $Date: 2003/06/12 23:41:36 $
+ */
+
