@@ -2,23 +2,23 @@
 #ifndef INCLUDED_FileBrowserControl_h_
 #define INCLUDED_FileBrowserControl_h_
 
-#include "MenuControl.h"
+#include "ControlBase.h"
 #include <string>
 #include <vector>
 
-//! Displays the contents of a directory in a MenuControl, probably useful as a baseclass for other controls
+//! Displays the contents of a directory in a control menu, probably useful as a baseclass for other controls
 /*! Causes the selectedFile() function to be called on the root FileBrowserControl with the selected file */
-class FileBrowserControl : public MenuControl {
+class FileBrowserControl : public ControlBase {
 public:
 	//!@name Constructors/Destructors
 	//!constructor
-	FileBrowserControl() : MenuControl(), recurse(true), root(""), paths(), filter("*") {}
+	FileBrowserControl() : ControlBase(), recurse(true), root(), paths(), filter("*") {init("");}
 	//!constructor pass name and root path
-	FileBrowserControl(const std::string& nm, const std::string& path) : MenuControl(nm), recurse(true), root(), paths(), filter("*") { setRoot(path); }
+	FileBrowserControl(const std::string& nm, const std::string& desc, const std::string& path) : ControlBase(nm,desc), recurse(true), root(), paths(), filter("*") { init(path); }
 	//@}
 	
 	//!@name ControlBase Inheritance
-	virtual ControlBase * activate(MotionManager::MC_ID display);
+	virtual ControlBase * activate(MotionManager::MC_ID display, Socket * gui);
 	virtual ControlBase* doSelect();
 	//@}
 
@@ -52,6 +52,9 @@ protected:
 	//!rescans current directory and builds menus
 	void rebuildmenu();
 
+	//!sets a junk menu item to mark this as having submenus, and sets root to path
+	void init(std::string path) { pushSlot(NULL); setRoot(path); }
+
 	bool recurse;                   //!< if true (default), will show directories; if false, subdirectories are hidden
 	std::string root;               //!< the path to browse, default "/"
 	std::vector<std::string> paths; //!< list of directories from root
@@ -68,10 +71,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_2 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-1_3 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2003/04/30 03:55:49 $
+ * $Date: 2003/06/10 00:53:48 $
  */
 
 #endif
