@@ -14,7 +14,7 @@ class LoadPostureControl : public FileBrowserControl, public EventListener {
  public:
 	//! Constructor
 	LoadPostureControl(const std::string& n, MotionManager::MC_ID estop_id)
-		: FileBrowserControl(n,config->motion.root), estopid(estop_id), file()
+		: FileBrowserControl(n,"Loads a posture from user-selected file",config->motion.root), estopid(estop_id), file()
 	{
 		setFilter("*.pos");
 	}
@@ -31,6 +31,11 @@ class LoadPostureControl : public FileBrowserControl, public EventListener {
 		// estop senses forces on the joints - the force of snapping the joint
 		// into position will cause it to reset and not make it into position
 		estop->LoadFile(file.c_str());
+		estop->setActive(true);
+	}
+	
+	virtual void deactivate() {
+		erouter->forgetListener(this);
 	}
 
 protected:
@@ -39,7 +44,7 @@ protected:
 		file=f;
 		SharedObject<PostureMC> post;
 		post->LoadFile(file.c_str());
-		//		post->setTolerance(.05);
+		MMAccessor<EmergencyStopMC>(estopid)->setActive(false);
 		MotionManager::MC_ID id=motman->addMotion(post,MotionManager::kEmergencyPriority+1,true);
 		erouter->addListener(this,EventBase::motmanEGID,id,EventBase::deactivateETID);
 		return this;
@@ -54,10 +59,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_2 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-1_3 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2003/04/30 03:55:49 $
+ * $Date: 2003/06/10 00:53:48 $
  */
 
 #endif
