@@ -6,12 +6,12 @@
 #include "Shared/Config.h"
 #include <string>
 
-//! When activated, loads a set of walk parameters from a file read from cin
+//! When activated, loads a set of walk parameters from a file specified by user
 class LoadWalkControl : public FileBrowserControl {
 public:
 	//! constructor, pass the MC_ID of the WalkMC which you want to save
 	LoadWalkControl(const std::string& n, MotionManager::MC_ID w)
-		: FileBrowserControl(n,config->motion.root), walk_id(w)
+		: FileBrowserControl(n,"Loads a set of walk parameters from a file specified by user",config->motion.root), walk_id(w)
 	{
 		setFilter("*.prm");
 	}
@@ -35,10 +35,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_2 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-1_3 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2003/04/29 18:33:00 $
+ * $Date: 2003/06/10 00:53:48 $
  */
 
 #endif
